==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/LabelDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { InputGroupItemDescriptionMetadata } from "./InputGroupItemDescriptionMetadata";
import { LabelDescription } from "./LabelDescription";
/**
 * @hidden
 */
var LabelDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(LabelDescriptionMetadata, _super);
    function LabelDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    LabelDescriptionMetadata.b = function (a) {
        if (LabelDescriptionMetadata.a == null) {
            LabelDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            LabelDescriptionMetadata.c(LabelDescriptionMetadata.a);
        }
        if (a.g(LabelDescriptionMetadata.a)) {
            return;
        }
        a.s(LabelDescriptionMetadata.a);
    };
    LabelDescriptionMetadata.c = function (a) {
        InputGroupItemDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:XLabel");
        a.item("BaseTheme", "ExportedType:string:BaseControlTheme");
        a.item("BaseTheme@names", "Default;DenaliLight;MaterialLight");
        a.item("Density", "ExportedType:string:ControlDisplayDensity");
        a.item("Density@names", "Auto;Comfortable;Cosy;Compact");
        a.item("ActualDensity", "ExportedType:string:ControlDisplayDensity");
        a.item("ActualDensity@names", "Auto;Comfortable;Cosy;Compact");
        a.item("ActualTextColor", "Brush");
        a.item("ActualHighlightTextColor", "Brush");
        a.item("ActualHoverHighlightTextColor", "Brush");
        a.item("ActualHoverTextColor", "Brush");
        a.item("TextColor", "Brush");
        a.item("HighlightTextColor", "Brush");
        a.item("HoverHighlightTextColor", "Brush");
        a.item("FontFamily", "(w:FontFamily/FontFamilyTransform,xam:FontFamily,wf:FontFamily,web:textStyle/FontFamilyTransform)String");
        a.item("FontSize", "(w:FontSize,xam:FontSize,wf:FontSize,web:textStyle/FontSizeTransform)Number:double");
        a.item("FontStyle", "(w:FontStyle/FontStyleTransform,xam:FontFamily/FontStyleTransform,wf:FontFamily/FontStyleTransform,web:textStyle/FontStyleTransform)String");
        a.item("FontWeight", "(w:FontWeight/FontWeightTransform,xam:FontFamily/FontWeightTransform,wf:FontFamily/FontWeightTransform,web:textStyle/FontWeightTransform)String");
        a.item("HoverTextColor", "Brush");
        a.item("Id", "String");
        a.item("Display", "String");
        a.item("FlexDirection", "String");
        a.item("FlexGrow", "String");
        a.item("AlignItems", "String");
        a.item("AlignSelf", "String");
        a.item("TabIndex", "Number:int");
        a.item("For", "(w:ForAttribute,xam:ForAttribute,wf:ForAttribute)String");
        a.item("AriaLabel", "String");
        a.item("Text", "String");
        a.item("IsHover", "Boolean");
        a.item("Value", "Boolean");
        a.item("Disabled", "(w:IsDisabled,xam:IsDisabled,wf:IsDisabled)Boolean");
    };
    LabelDescriptionMetadata.d = function (a) {
        LabelDescriptionMetadata.b(a);
        a.u("Label", function () { return new LabelDescription(); });
        a.t("Label", LabelDescriptionMetadata.a);
    };
    LabelDescriptionMetadata.$t = markType(LabelDescriptionMetadata, 'LabelDescriptionMetadata');
    LabelDescriptionMetadata.a = null;
    return LabelDescriptionMetadata;
}(Base));
export { LabelDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/LabelDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { InputGroupItemDescriptionMetadata } from "./InputGroupItemDescriptionMetadata";
import { LabelDescription } from "./LabelDescription";
/**
 * @hidden
 */
var LabelDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(LabelDescriptionMetadata, _super);
    function LabelDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    LabelDescriptionMetadata.b = function (a) {
        if (LabelDescriptionMetadata.a == null) {
            LabelDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            LabelDescriptionMetadata.c(LabelDescriptionMetadata.a);
        }
        if (a.j(LabelDescriptionMetadata.a)) {
            return;
        }
        a.y(LabelDescriptionMetadata.a);
    };
    LabelDescriptionMetadata.c = function (a) {
        InputGroupItemDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:XLabel");
        a.item("BaseTheme", "ExportedType:string:BaseControlTheme");
        a.item("BaseTheme@names", "Default;DenaliLight;MaterialLight");
        a.item("Density", "ExportedType:string:ControlDisplayDensity");
        a.item("Density@names", "Auto;Comfortable;Cosy;Compact");
        a.item("ActualDensity", "ExportedType:string:ControlDisplayDensity");
        a.item("ActualDensity@names", "Auto;Comfortable;Cosy;Compact");
        a.item("ActualTextColor", "Brush");
        a.item("ActualHighlightTextColor", "Brush");
        a.item("ActualHoverHighlightTextColor", "Brush");
        a.item("ActualHoverTextColor", "Brush");
        a.item("TextColor", "Brush");
        a.item("HighlightTextColor", "Brush");
        a.item("HoverHighlightTextColor", "Brush");
        a.item("FontFamily", "(w:FontFamily/FontFamilyTransform,xam:FontFamily,wf:FontFamily,web:textStyle/FontFamilyTransform)String");
        a.item("FontSize", "(w:FontSize,xam:FontSize,wf:FontSize,web:textStyle/FontSizeTransform)Number:double");
        a.item("FontStyle", "(w:FontStyle/FontStyleTransform,xam:FontFamily/FontStyleTransform,wf:FontFamily/FontStyleTransform,web:textStyle/FontStyleTransform)String");
        a.item("FontWeight", "(w:FontWeight/FontWeightTransform,xam:FontFamily/FontWeightTransform,wf:FontFamily/FontWeightTransform,web:textStyle/FontWeightTransform)String");
        a.item("HoverTextColor", "Brush");
        a.item("Id", "String");
        a.item("Display", "String");
        a.item("FlexDirection", "String");
        a.item("FlexGrow", "String");
        a.item("AlignItems", "String");
        a.item("AlignSelf", "String");
        a.item("TabIndex", "Number:int");
        a.item("For", "(w:ForAttribute,xam:ForAttribute,wf:ForAttribute)String");
        a.item("AriaLabel", "String");
        a.item("Text", "String");
        a.item("IsHover", "Boolean");
        a.item("Value", "Boolean");
        a.item("Disabled", "(w:IsDisabled,xam:IsDisabled,wf:IsDisabled)Boolean");
    };
    LabelDescriptionMetadata.d = function (a) {
        LabelDescriptionMetadata.b(a);
        a.aa("Label", function () { return new LabelDescription(); });
        a.z("Label", LabelDescriptionMetadata.a);
    };
    LabelDescriptionMetadata.$t = markType(LabelDescriptionMetadata, 'LabelDescriptionMetadata');
    LabelDescriptionMetadata.a = null;
    return LabelDescriptionMetadata;
}(Base));
export { LabelDescriptionMetadata };
